pub enum ReceiveReport {
Packet {
packet_index: PacketIndex,
},
Duplicate {
packet_index: PacketIndex,
},
Ack {
packet_index: PacketIndex,
},
Ping,
Pong,
Noise {
skipped: usize,
},
Corrupted,
Incomplete {
needed: Option<usize>,
},
Error(Error),
}Expand description
Result of Engine::receive.
Variants
Packet
A packet envelope was accepted.
Fields

packet_index: PacketIndexPacket index decoded from the envelope.
Duplicate
A duplicate packet envelope was acknowledged but not processed again.
Fields

packet_index: PacketIndexDuplicate packet index.
Ack
An ACK packet was accepted.
Fields

packet_index: PacketIndexPacket index acknowledged by the peer.
Ping
A PING packet was accepted and a PONG was queued.
Pong
A PONG packet was accepted.
Noise
The input did not contain a valid magic prefix at offset zero.
Corrupted
The envelope integrity check failed.
Incomplete
The envelope is incomplete.
Error(Error)
The packet was valid but could not be applied to engine state.