pub enum ReliabilityMode {
Reliable,
BestEffort,
LatestOnly,
Deadline,
}Expand description
Reliability mode requested for a packet kind or message class.
Variants
Reliable
Require acknowledgement and allow retransmission.
BestEffort
Send without retransmission.
LatestOnly
Prefer the newest message and allow older messages to be dropped.
Deadline
Retransmit only while the engine-defined deadline remains valid.