pub enum EngineEvent {
MessageReceived {
channel_id: ChannelId,
message_key: MessageKey,
},
LinkWrite,
AckRequired {
packet_number: PacketNumber,
},
Retransmit {
packet_number: PacketNumber,
},
WakeAt(Instant),
Reliability(PacketReliabilityEvent),
}Expand description
Events emitted by the protocol engine to its embedding environment.
Variants
MessageReceived
A complete message is available for a channel.
Fields

message_key: MessageKeyMessage identity on the channel.
LinkWrite
A protocol response should be written to the lower link.
AckRequired
An ACK response should be generated for a packet.
Fields

packet_number: PacketNumberPacket number that should be acknowledged.
Retransmit
A retransmission became due.
Fields

packet_number: PacketNumberPacket number selected for retransmission.
WakeAt(Instant)
The engine needs to be ticked again at a later instant.
Reliability(PacketReliabilityEvent)
A packet-level reliability event occurred.
Implementations
Sourceimpl EngineEvent
impl EngineEvent
Sourcepub const fn kind(self) -> EngineEventKind
pub const fn kind(self) -> EngineEventKind
Returns this event’s kind.