pub trait Dedup {
// Required methods
fn observe(&mut self, key: PacketKey) -> DedupDecision;
fn is_duplicate(&self, key: PacketKey) -> bool;
}Expand description
Detects duplicate packet keys.
Required Methods
Sourcefn observe(&mut self, key: PacketKey) -> DedupDecision
fn observe(&mut self, key: PacketKey) -> DedupDecision
Observes a packet key and returns whether it should be processed.
Sourcefn is_duplicate(&self, key: PacketKey) -> bool
fn is_duplicate(&self, key: PacketKey) -> bool
Returns whether a packet key is already known as observed.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".